==> ci-auto-update-5.0.4.zip: elabftw_ynh/README_es.md <==
<!--
Este archivo README esta generado automaticamente<https://github.com/YunoHost/apps/tree/master/tools/readme_generator>
No se debe editar a mano.
-->

# eLabFTW para Yunohost

[![Nivel de integración](https://dash.yunohost.org/integration/elabftw.svg)](https://dash.yunohost.org/appci/app/elabftw) ![Estado funcional](https://ci-apps.yunohost.org/ci/badges/elabftw.status.svg) ![Estado En Mantención](https://ci-apps.yunohost.org/ci/badges/elabftw.maintain.svg)

[![Instalar eLabFTW con Yunhost](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=elabftw)

*[Leer este README en otros idiomas.](./ALL_README.md)*

> *Este paquete le permite instalareLabFTW rapidamente y simplement en un servidor YunoHost.*  
> *Si no tiene YunoHost, visita [the guide](https://yunohost.org/install) para aprender como instalarla.*

## Descripción general

eLabFTW is an electronic lab notebook manager for research teams.

It lets you store and organize your research experiments easily. It also features a database where any kind of objects (such as antibodies, plasmids, cell lines, boxes, etc.) can be stored. It is accessed via the browser. Several research teams can be hosted on the same installation. This means eLabFTW can be installed at the institute level and host all team members at the same place. This is what is done at Institut Curie and in several other research centers around the globe.

**Versión actual:** 5.0.4~ynh1

**Demo:** <https://demo.elabftw.net/login.php>

## Capturas

![Captura de eLabFTW](./doc/screenshots/screen-1.jpg)

## Documentaciones y recursos

- Sitio web oficial: <https://www.elabftw.net>
- Documentación administrador oficial: <https://doc.elabftw.net/>
- Repositorio del código fuente oficial de la aplicación : <https://github.com/elabftw/elabftw>
- Catálogo YunoHost: <https://apps.yunohost.org/app/elabftw>
- Reportar un error: <https://github.com/YunoHost-Apps/elabftw_ynh/issues>

## Información para desarrolladores

Por favor enviar sus correcciones a la [`branch testing`](https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing

Para probar la rama `testing`, sigue asÍ:

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing --debug
o
sudo yunohost app upgrade elabftw -u https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing --debug
```

**Mas informaciones sobre el empaquetado de aplicaciones:** <https://yunohost.org/packaging_apps>

==> ci-auto-update-5.1.2.zip: elabftw_ynh/README_es.md <==
<!--
Este archivo README esta generado automaticamente<https://github.com/YunoHost/apps/tree/master/tools/readme_generator>
No se debe editar a mano.
-->

# eLabFTW para Yunohost

[![Nivel de integración](https://dash.yunohost.org/integration/elabftw.svg)](https://ci-apps.yunohost.org/ci/apps/elabftw/) ![Estado funcional](https://ci-apps.yunohost.org/ci/badges/elabftw.status.svg) ![Estado En Mantención](https://ci-apps.yunohost.org/ci/badges/elabftw.maintain.svg)

[![Instalar eLabFTW con Yunhost](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=elabftw)

*[Leer este README en otros idiomas.](./ALL_README.md)*

> *Este paquete le permite instalareLabFTW rapidamente y simplement en un servidor YunoHost.*  
> *Si no tiene YunoHost, visita [the guide](https://yunohost.org/install) para aprender como instalarla.*

## Descripción general

eLabFTW is an electronic lab notebook manager for research teams.

It lets you store and organize your research experiments easily. It also features a database where any kind of objects (such as antibodies, plasmids, cell lines, boxes, etc.) can be stored. It is accessed via the browser. Several research teams can be hosted on the same installation. This means eLabFTW can be installed at the institute level and host all team members at the same place. This is what is done at Institut Curie and in several other research centers around the globe.

**Versión actual:** 5.1.2~ynh1

**Demo:** <https://demo.elabftw.net/login.php>

## Capturas

![Captura de eLabFTW](./doc/screenshots/screen-1.jpg)

## Documentaciones y recursos

- Sitio web oficial: <https://www.elabftw.net>
- Documentación administrador oficial: <https://doc.elabftw.net/>
- Repositorio del código fuente oficial de la aplicación : <https://github.com/elabftw/elabftw>
- Catálogo YunoHost: <https://apps.yunohost.org/app/elabftw>
- Reportar un error: <https://github.com/YunoHost-Apps/elabftw_ynh/issues>

## Información para desarrolladores

Por favor enviar sus correcciones a la [`branch testing`](https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing

Para probar la rama `testing`, sigue asÍ:

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing --debug
o
sudo yunohost app upgrade elabftw -u https://github.com/YunoHost-Apps/elabftw_ynh/tree/testing --debug
```

**Mas informaciones sobre el empaquetado de aplicaciones:** <https://yunohost.org/packaging_apps>
